@@ -5,18 +5,16 @@
 #' of responses, general metadata, survey flow, etc.
 #'
 #' @param surveyID A string. Unique ID for the survey you want to download.
-#' Returned as "id" by the [all_surveys] function.
+#'   Returned as "id" by the [all_surveys] function.
 #' @param get A character vector containing any of the following: "metadata",
-#' "questions", "responsecounts", "blocks", "flow", "embedded_data",
-#' or "comments". Will return included elements. By default, the function
-#' returns the "metadata", "questions", and "responsecounts" elements.
-#' See examples below for more information.
-#' @param ... Additional options. User may pass an argument called `questions`,
-#' a vector containing the names of questions for which you want to
-#' return metadata.
+#'   "questions", "responsecounts", "blocks", "flow", "embedded_data", or
+#'   "comments". Will return included elements. By default, the function returns
+#'   the "metadata", "questions", and "responsecounts" elements. See examples
+#'   below for more information.
+#' @param questions Character vector containing the names of questions for which
+#'   you want to return metadata.  Defaults to NULL (all questions).
 #'
 #' @template retry-advice
-#' @importFrom assertthat assert_that
 #' @export
 #' @examples
 #' \dontrun{
@@ -54,67 +52,16 @@
 #'
 metadata <- function(surveyID,
                      get = NULL,
-                     ...) {
+                     questions = NULL) {
 
   # OPTIONS AND PREP ----
 
   # Check params
-  assert_base_url()
-  assert_api_key()
+  check_credentials()
+  checkarg_isstring(surveyID)
 
-  # Deal with old list format for get parameter:
-  if(is.list(get)){
-    message("Use of logical lists for argument 'get' has been deprecated.
-    In future, use a character vector including desired elements")
-
-    # Pull out the TRUE elements of the list:
-    get_true <- names(get)[unlist(get)]
-    # Pull out the FALSE elements of the list:
-    get_false <- names(get)[!unlist(get)]
-
-    # Restore old behavior when using lists (metadata, questions, responsecounts
-    # included unless specifically specified as FALSE):
-    get <-
-      setdiff(
-        union(c("metadata", "questions", "responsecounts"),
-                 get_true),
-        get_false)
-
-  }
-
-  if(is.null(get)){
-
-    # Set default options for argument 'get'
-    get <- c("metadata", "questions", "responsecounts")
-
-  } else {
-
-    # Check if illegal options were passed to get by user
-    allowed <- c(
-      "metadata", "questions", "responsecounts",
-      "blocks", "flow", "embedded_data", "comments"
-    )
-
-    # Make case insensitive:
-    get <- tolower(get)
-
-    assertthat::assert_that(
-      all(get %in% allowed), # nolint
-      msg = "One or more entries in 'get' are not valid. Please check your\ninput and try again."
-    ) # nolint
-
-  }
-  # Other options
-  opts <- list(...)
-  if ("questions" %in% names(opts)) {
-    # Check that is a vector
-    assertthat::assert_that(is.vector(opts$questions),
-                            msg = "'questions' argument must be a vector"
-    )
-    q_select <- opts$questions
-  } else {
-    q_select <- NULL
-  }
+  get <- checkarg_get(get)
+  checkarg_ischaracter(questions)
 
   # QUERY API ----
 
@@ -156,21 +103,22 @@ metadata <- function(surveyID,
   )
 
   # Metadata about questions
-  if (!is.null(q_select)) {
+  if (!is.null(questions)) {
     qnames <- vapply(resp_filt$questions, function(x) {
       x$questionName
     }, "")
-    if (all(q_select %in% qnames)) {
-      questions <- resp_filt$questions[which(qnames %in% q_select)]
+    if (all(questions %in% qnames)) {
+      qs_toreturn <-
+        resp_filt$questions[which(qnames %in% questions)]
     } else {
       rlang::warn(
         paste0("One or more questions you queried are not present in your survey.",
                "\nReturning all questions instead.")
       ) # nolint
-      questions <- resp_filt$questions
+      qs_toreturn <- resp_filt$questions
     }
   } else {
-    questions <- resp_filt$questions
+    qs_toreturn <- resp_filt$questions
   }
 
   # WRAP UP AND RETURN ----
@@ -178,7 +126,7 @@ metadata <- function(surveyID,
   # Construct metadata
   met <- list(
     "metadata" = metadata,
-    "questions" = questions,
+    "questions" = qs_toreturn,
     "responsecounts" = responsecounts,
     "blocks" = resp_filt$blocks,
     "flow" = resp_filt$flow,
