@@ -3,11 +3,14 @@ skip_on_cran()
 skip_on_ci()
 
 test_that("list_distribution_links() returns a tbl_df with expected column names and types", {
-  local_mocked_bindings(glue_api_v3 = function(base_url) "https://stoplight.io/mocks/qualtricsv2/publicapidocs/60919")
+  local_mocked_bindings(
+    glue_api_v3 = function(base_url)
+      "https://stoplight.io/mocks/qualtricsv2/publicapidocs/60919"
+  )
 
   x <- list_distribution_links("EMD_abcdef123456789", "SV_abcdef123456789")
   expect_s3_class(x, c("tbl_df", "tbl", "data.frame"))
-  expect_s3_class(x$linkExpiration,  c("POSIXct", "POSIXt"))
+  expect_s3_class(x$linkExpiration, c("POSIXct", "POSIXt"))
 
   expect_type(x$contactId, "character")
   expect_type(x$transactionId, "character")
@@ -19,5 +22,4 @@ test_that("list_distribution_links() returns a tbl_df with expected column names
   expect_type(x$externalDataReference, "character")
   expect_type(x$email, "character")
   expect_type(x$unsubscribed, "logical")
-
 })
